OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Instrumentpanel",
    "Dashboard app" : "Instrumentpanel app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Start dagen din informert\n\nNextcloud-kontrollpanel er ditt utgangspunkt for dagen, og gir deg en oversikt over dine kommende avtaler, presserende e-poster, chatmeldinger, innkommende billetter, siste tvitringer og mye mer! Brukere kan legge til widgetene de liker og endre bakgrunnen etter eget ønske.",
    "\"{title} icon\"" : "\"{title} ikon\"",
    "Customize" : "Tilpass",
    "Edit widgets" : "Rediger widgets",
    "Get more widgets from the App Store" : "Få flere widgets fra app-butikken",
    "Weather service" : "Værmelding",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Av hensyn til personvernet ditt blir værdataene bedt om av Nextcloud-serveren din på dine vegne, slik at værtjenesten ikke mottar personlig informasjon.",
    "Weather data from Met.no" : "Værmelding fra Met.no",
    "geocoding with Nominatim" : "geokoding med Nominatim",
    "elevation data from OpenTopoData" : "høydedata fra OpenTopoData",
    "Weather" : "Vær",
    "Status" : "Status",
    "Good morning" : "God morgen",
    "Good morning, {name}" : "God morgen, {name}",
    "Good afternoon" : "God ettermiddag",
    "Good afternoon, {name}" : "Good ettermiddag, {name}",
    "Good evening" : "God kveld",
    "Good evening, {name}" : "God kveld, {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start dagen din informert \n\nNextcloud skrivebordet er starte punktet ditt for dagen, gir deg kommende møter, viktig email, chat-meldinger\ninnkommende biletter, seneste tweets og mye mer! Brukere kan legge til widgeter\nde liker og forandre bakgrunnen etter deres smak.",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Start dagen din informert\n\nNextcloud-kontrollpanel er ditt utgangspunkt for dagen, og gir deg en oversikt over dine kommende avtaler, presserende e-poster, chatmeldinger, innkommende billetter, siste tvitringer og mye mer! Brukere kan legge til widgetene de liker og endre bakgrunnen etter eget ønske."
},
"nplurals=2; plural=(n != 1);");
